
# Type: values_from


the identifier of a "value set" -- a set of identifiers that form the possible values for the range of a slot

URI: [meta:values_from](https://w3id.org/biolink/biolinkml/meta/values_from)


## Domain and Range

[Definition](Definition.md) ->  <sub>0..*</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [SlotDefinition](SlotDefinition.md)
